=========
Changelog
=========

..
    Version 0.1.2 (development)
    ===========================


Version 0.1.1
=============

- Improved lookup for django-admin via ``pyscaffold.shell.get_command``, see issue #3
- Fix invalid cache in Cirrus CI by using a fingerprint script


Version 0.1
===========

- Initial release extracted from PyScaffold
- Updated to PyScaffold v4
- Added ``__main__.py`` and custom ``manage.py`` to bypass Django's packaging limitations, PR #2
- Added support for project path different from package name
